@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-07-02'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2015-07-06'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -292,22 +292,27 @@ sub gen_inline_pericmd_script {
 
         my %copts;
         {
+            my $skip_format = $meta->{'cmdline.skip_format'};
+
             require Perinci::CmdLine::Base;
             no warnings 'once';
-            for (qw/help version json format/) {
-                $copts{$_} = $Perinci::CmdLine::Base::copts{$_};
+            $copts{help} = $Perinci::CmdLine::Base::copts{help};
+            $copts{version} = $Perinci::CmdLine::Base::copts{version};
+            unless ($skip_format) {
+                $copts{json} = $Perinci::CmdLine::Base::copts{json};
+                $copts{format} = $Perinci::CmdLine::Base::copts{format};
+                # "naked_res!" currently not supported by
+                # Getopt::Long::EvenLess, so we split it. the downside is that
+                # we don't hide the default, by default.
+                $copts{naked_res} = {
+                    getopt  => "naked-res",
+                    summary => "When outputing as JSON, strip result envelope",
+                };
+                $copts{no_naked_res} = {
+                    getopt  => "no-naked-res|nonaked-res",
+                    summary => "When outputing as JSON, don't strip result envelope",
+                };
             }
-            # "naked_res!" currently not supported by Getopt::Long::EvenLess, so
-            # we split it. the downside is that we don't hide the default, by
-            # default.
-            $copts{naked_res} = {
-                getopt  => "naked-res",
-                summary => "When outputing as JSON, strip result envelope",
-            };
-            $copts{no_naked_res} = {
-                getopt  => "no-naked-res|nonaked-res",
-                summary => "When outputing as JSON, don't strip result envelope",
-            };
         }
 
         my $shebang_line;
@@ -681,7 +686,7 @@ _
         push @l, "# display result\n\n";
         push @l, "{\n";
         push @l, 'my $fres;', "\n";
-        push @l, 'if ($_pci_r->{res}[3]{"cmdline.skip_format"}) { $fres = $_pci_r->{res}[2] } else { require Inlined::_pci_format_result; $fres = _pci_format_result($_pci_r) }', "\n";
+        push @l, 'if (', ($meta->{'cmdline.skip_format'} ? 1:0), ' || $_pci_r->{res}[3]{"cmdline.skip_format"}) { $fres = $_pci_r->{res}[2] } else { require Inlined::_pci_format_result; $fres = _pci_format_result($_pci_r) }', "\n";
         push @l, 'print $fres;', "\n";
         push @l, "}\n\n";
 
@@ -815,7 +820,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.13 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-02.
+This document describes version 0.14 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-06.
 
 =head1 SYNOPSIS
 
@@ -841,23 +846,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                  Rate  run 1 (lite) run --version (lite)    -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
- run 1 (lite)           13.461+-0.03/s            --               -61.7%       -82.8%         -88.4%                 -91.7%      -92.4% -97.4%
- run --version (lite)     35.18+-0.1/s 161.31+-0.95%                   --       -55.0%         -69.8%                 -78.3%      -80.2% -93.2%
- -c (lite)               78.13+-0.21/s     480.4+-2%        122.11+-0.87%           --         -32.9%                 -51.9%      -56.1% -85.0%
- run 1 (inline)         116.47+-0.89/s   765.2+-6.9%          231.1+-2.7%   49.1+-1.2%             --                 -28.3%      -34.6% -77.6%
- run --version (inline) 162.43+-0.47/s  1106.7+-4.4%          361.8+-1.9% 107.9+-0.82%     39.5+-1.1%                     --       -8.8% -68.7%
- -c (inline)              178.1+-1.3/s  1222.7+-9.9%          406.2+-3.9%  127.9+-1.7%     52.9+-1.6%            9.62+-0.84%          -- -65.7%
- perl                     519.3+-7.2/s     3758+-54%            1376+-21%  564.7+-9.4%      345.9+-7%            219.7+-4.5% 191.7+-4.5%     --
+                                     Rate  run 1 (lite) run --version (lite)     -c (lite) run 1 (inline) run --version (inline)   -c (inline)   perl
+ run 1 (lite)           21.1108+-0.0094/s            --               -62.9%        -83.3%         -89.2%                 -91.6%        -93.8% -97.4%
+ run --version (lite)     56.935+-0.032/s 169.69+-0.19%                   --        -55.0%         -71.0%                 -77.4%        -83.2% -93.0%
+ -c (lite)               126.433+-0.073/s        498.9%        122.07+-0.18%            --         -35.5%                 -49.7%        -62.6% -84.4%
+ run 1 (inline)             196.1+-0.33/s   828.9+-1.6%         244.44+-0.6%   55.1+-0.27%             --                 -22.0%        -42.1% -75.8%
+ run --version (inline)    251.53+-0.18/s       1091.5%         341.78+-0.4%  98.94+-0.18%   28.26+-0.23%                     --        -25.7% -69.0%
+ -c (inline)                338.5+-0.46/s  1503.4+-2.3%        494.53+-0.87% 167.73+-0.39%   72.61+-0.37%           34.58+-0.21%            -- -58.3%
+ perl                      811.32+-0.32/s       3743.2%              1325.0%        541.7%  313.72+-0.71%          222.56+-0.27% 139.68+-0.34%     --
  
  Average times:
-   perl                  :     1.9257ms
-   -c (inline)           :     5.6148ms
-   run --version (inline):     6.1565ms
-   run 1 (inline)        :     8.5859ms
-   -c (lite)             :    12.7992ms
-   run --version (lite)  :    28.4252ms
-   run 1 (lite)          :    74.2887ms
+   perl                  :     1.2326ms
+   -c (inline)           :     2.9542ms
+   run --version (inline):     3.9757ms
+   run 1 (inline)        :     5.0994ms
+   -c (lite)             :     7.9093ms
+   run --version (lite)  :    17.5639ms
+   run 1 (lite)          :    47.3691ms
 
 =head1 FUNCTIONS
 
